@@ -33,23 +33,25 @@
 #include <unistd.h>
 #include <inttypes.h>
 #include <sys/ioctl.h>
+#include <cmath>
 
 // We declare an auto pointer to WandererBoxProV3.
 static std::unique_ptr<WandererBoxProV3> wandererboxprov3(new WandererBoxProV3());
 
 
 
-WandererBoxProV3::WandererBoxProV3()
+WandererBoxProV3::WandererBoxProV3() : INDI::DefaultDevice(), INDI::WeatherInterface(this)
 {
-    setVersion(1, 0);
+    setVersion(1, 1);
 }
 
 bool WandererBoxProV3::initProperties()
 {
 
     INDI::DefaultDevice::initProperties();
-    setDriverInterface(AUX_INTERFACE);
+    setDriverInterface(AUX_INTERFACE | WEATHER_INTERFACE);
 
+    WI::initProperties(ENVIRONMENT_TAB, ENVIRONMENT_TAB);
 
     addAuxControls();
 
@@ -165,7 +167,13 @@ bool WandererBoxProV3::initProperties()
     ENVMonitorNP[ENV_Humidity].fill( "ENV_Humidity", "Ambient Humidity %", "%4.2f", 0, 999, 100, 0);
     ENVMonitorNP[ENV_Temp].fill( "ENV_Temp", "Ambient Temperature (C)", "%4.2f", 0, 999, 100, 0);
     ENVMonitorNP[DEW_Point].fill( "DEW_Point", "Dew Point (C)", "%4.2f", 0, 999, 100, 0);
-    ENVMonitorNP.fill(getDeviceName(), "ENV_Monitor", "Environment",ENVIRONMENT_TAB, IP_RO,60, IPS_IDLE);
+    ENVMonitorNP.fill(getDeviceName(), "ENV_Monitor", "Environment", SENSORS_TAB, IP_RO,60, IPS_IDLE);
+
+    // Weather Interface Parameters
+    addParameter("WEATHER_TEMPERATURE", "Temperature (C)", -15, 35, 15);
+    addParameter("WEATHER_HUMIDITY", "Humidity %", 0, 100, 15);
+    addParameter("WEATHER_DEWPOINT", "Dew Point (C)", 0, 100, 15);
+    setCriticalParameter("WEATHER_TEMPERATURE");
     serialConnection = new Connection::Serial(this);
     serialConnection->setDefaultBaudRate(Connection::Serial::B_19200);
     serialConnection->registerHandshake([&]()
@@ -578,10 +586,19 @@ void WandererBoxProV3::updateENV(double temp1,double temp2,double temp3,double D
     ENVMonitorNP[Probe3_Temp].setValue(temp3);
     ENVMonitorNP[ENV_Humidity].setValue(DHTH);
     ENVMonitorNP[ENV_Temp].setValue(DHTT);
-    ENVMonitorNP[DEW_Point].setValue((237.7 * ((17.27 * DHTT) / (237.7 + DHTT) + log((DHTH / 100)))) / (17.27 - ((17.27 * DHTT) / (237.7 + DHTT) + log((DHTH / 100)))));;
+    double dewPoint = (237.7 * ((17.27 * DHTT) / (237.7 + DHTT) + std::log((DHTH / 100)))) / (17.27 - ((17.27 * DHTT) / (237.7 + DHTT) + std::log((DHTH / 100))));
+    ENVMonitorNP[DEW_Point].setValue(dewPoint);
     ENVMonitorNP.setState(IPS_OK);
     ENVMonitorNP.apply();
 
+    // Update Weather Interface parameters
+    setParameterValue("WEATHER_TEMPERATURE", DHTT);
+    setParameterValue("WEATHER_HUMIDITY", DHTH);
+    setParameterValue("WEATHER_DEWPOINT", dewPoint);
+    ParametersNP.setState(IPS_OK);
+    ParametersNP.apply();
+    if (syncCriticalParameters())
+        critialParametersLP.apply();
 }
 
 
@@ -787,6 +804,8 @@ bool WandererBoxProV3::updateProperties()
 
         defineProperty(ENVMonitorNP);
 
+        // Weather
+        WI::updateProperties();
 
     }
     else
@@ -796,6 +815,9 @@ bool WandererBoxProV3::updateProperties()
         deleteProperty(PowerMonitorNP);
         deleteProperty(ENVMonitorNP);
 
+        // Weather
+        WI::updateProperties();
+
         deleteProperty(dc3_4ControlSP);
         deleteProperty(setDC34voltageNP);
         deleteProperty(dc8_9ControlSP);
@@ -826,6 +848,12 @@ bool WandererBoxProV3::updateProperties()
 
 bool WandererBoxProV3::ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n)
 {
+    if (dev && !strcmp(dev, getDeviceName()))
+    {
+        if (strstr(name, "WEATHER_"))
+            return WI::processSwitch(dev, name, states, names, n);
+    }
+
     // Calibrate
     if (CalibrateSP.isNameMatch(name))
     {
@@ -1138,6 +1166,8 @@ bool WandererBoxProV3::ISNewNumber(const char * dev, const char * name, double v
 {
     if (dev && !strcmp(dev, getDeviceName()))
     {
+        if (strstr(name, "WEATHER_"))
+            return WI::processNumber(dev, name, values, names, n);
         // DC5
         if (dc5ControlNP.isNameMatch(name))
         {
@@ -1306,6 +1336,7 @@ void WandererBoxProV3::TimerHit()
 bool WandererBoxProV3::saveConfigItems(FILE * fp)
 {
     INDI::DefaultDevice::saveConfigItems(fp);
+    WI::saveConfigItems(fp);
 
     dc5diffSP.save(fp);
     dc5diffSETNP.save(fp);
@@ -1326,3 +1357,11 @@ bool WandererBoxProV3::saveConfigItems(FILE * fp)
     return true;
 }
 
+IPState WandererBoxProV3::updateWeather()
+{
+    // Weather is updated in updateENV() which is called from getData()
+    // This method is required by WeatherInterface but we update weather
+    // synchronously with sensor data, so we just return OK
+    return IPS_OK;
+}
+
