@@ -80,24 +80,24 @@ bool PegasusFocusCube::initProperties()
                      0, IPS_IDLE);
 
     // Relative and absolute movement
-    FocusRelPosN[0].min   = 0.;
-    FocusRelPosN[0].max   = 50000.;
-    FocusRelPosN[0].value = 0;
-    FocusRelPosN[0].step  = 1000;
+    FocusRelPosNP[0].setMin(0.);
+    FocusRelPosNP[0].setMax(50000.);
+    FocusRelPosNP[0].setValue(0);
+    FocusRelPosNP[0].setStep(1000);
 
-    FocusAbsPosN[0].min   = 0.;
-    FocusAbsPosN[0].value = 0;
-    FocusAbsPosN[0].step  = 1000;
+    FocusAbsPosNP[0].setMin(0.);
+    FocusAbsPosNP[0].setValue(0);
+    FocusAbsPosNP[0].setStep(1000);
 
     // Backlash compensation
-    FocusBacklashN[0].min   = 1; // 0 is off.
-    FocusBacklashN[0].max   = 10000;
-    FocusBacklashN[0].value = 1;
-    FocusBacklashN[0].step  = 1;
+    FocusBacklashNP[0].setMin(1); // 0 is off.
+    FocusBacklashNP[0].setMax(10000);
+    FocusBacklashNP[0].setValue(1);
+    FocusBacklashNP[0].setStep(1);
 
-    FocusMaxPosN[0].max = 1317500;
-    FocusMaxPosN[0].value = 1317500;
-    FocusAbsPosN[0].max = 1317500;
+    FocusMaxPosNP[0].setMax(1317500);
+    FocusMaxPosNP[0].setValue(1317500);
+    FocusAbsPosNP[0].setMax(1317500);
 
     //LED Default ON
     LEDS[LED_ON].s = ISS_ON;
@@ -399,10 +399,10 @@ bool PegasusFocusCube::updateFocusParams()
     }
 
     currentPosition = atoi(token);
-    if (currentPosition != FocusAbsPosN[0].value)
+    if (currentPosition != FocusAbsPosNP[0].getValue())
     {
-        FocusAbsPosN[0].value = currentPosition;
-        IDSetNumber(&FocusAbsPosNP, nullptr);
+        FocusAbsPosNP[0].setValue(currentPosition);
+        FocusAbsPosNP.apply();
     }
 
     // #6 Moving Status
@@ -446,11 +446,11 @@ bool PegasusFocusCube::updateFocusParams()
     int reverseStatus = atoi(token);
     if (reverseStatus >= 0 && reverseStatus <= 1)
     {
-        IUResetSwitch(&FocusReverseSP);
-        FocusReverseS[INDI_ENABLED].s = (reverseStatus == 1) ? ISS_ON : ISS_OFF;
-        FocusReverseS[INDI_DISABLED].s = (reverseStatus == 0) ? ISS_ON : ISS_OFF;
-        FocusReverseSP.s = IPS_OK;
-        IDSetSwitch(&FocusReverseSP, nullptr);
+        FocusReverseSP.reset();
+        FocusReverseSP[INDI_ENABLED].setState((reverseStatus == 1) ? ISS_ON : ISS_OFF);
+        FocusReverseSP[INDI_DISABLED].setState((reverseStatus == 0) ? ISS_ON : ISS_OFF);
+        FocusReverseSP.setState(IPS_OK);
+        FocusReverseSP.apply();
     }
 
     // #9 Encoder status
@@ -482,30 +482,30 @@ bool PegasusFocusCube::updateFocusParams()
 
     int backlash = atoi(token);
     // If backlash is zero then compensation is disabled
-    if (backlash == 0 && FocusBacklashS[INDI_ENABLED].s == ISS_ON)
+    if (backlash == 0 && FocusBacklashSP[INDI_ENABLED].getState() == ISS_ON)
     {
         LOG_WARN("Backlash value is zero, disabling backlash switch...");
 
-        FocusBacklashS[INDI_ENABLED].s = ISS_OFF;
-        FocusBacklashS[INDI_DISABLED].s = ISS_ON;
-        FocusBacklashSP.s = IPS_IDLE;
-        IDSetSwitch(&FocusBacklashSP, nullptr);
+        FocusBacklashSP[INDI_ENABLED].setState(ISS_OFF);
+        FocusBacklashSP[INDI_DISABLED].setState(ISS_ON);
+        FocusBacklashSP.setState(IPS_IDLE);
+        FocusBacklashSP.apply();
     }
-    else if (backlash > 0 && (FocusBacklashS[INDI_DISABLED].s == ISS_ON || backlash != FocusBacklashN[0].value))
+    else if (backlash > 0 && (FocusBacklashSP[INDI_DISABLED].getState() == ISS_ON || backlash != FocusBacklashNP[0].getValue()))
     {
-        if (backlash != FocusBacklashN[0].value)
+        if (backlash != FocusBacklashNP[0].getValue())
         {
-            FocusBacklashN[0].value = backlash;
-            FocusBacklashNP.s = IPS_OK;
-            IDSetNumber(&FocusBacklashNP, nullptr);
+            FocusBacklashNP[0].setValue(backlash);
+            FocusBacklashNP.setState(IPS_OK);
+            FocusBacklashNP.apply();
         }
 
-        if (FocusBacklashS[INDI_DISABLED].s == ISS_ON)
+        if (FocusBacklashSP[INDI_DISABLED].getState() == ISS_ON)
         {
-            FocusBacklashS[INDI_ENABLED].s = ISS_OFF;
-            FocusBacklashS[INDI_DISABLED].s = ISS_ON;
-            FocusBacklashSP.s = IPS_IDLE;
-            IDSetSwitch(&FocusBacklashSP, nullptr);
+            FocusBacklashSP[INDI_ENABLED].setState(ISS_OFF);
+            FocusBacklashSP[INDI_DISABLED].setState(ISS_ON);
+            FocusBacklashSP.setState(IPS_IDLE);
+            FocusBacklashSP.apply();
         }
     }
 
@@ -643,7 +643,7 @@ bool PegasusFocusCube::SetFocuserBacklashEnabled(bool enabled)
     if (!enabled)
         return SetFocuserBacklash(0);
 
-    return SetFocuserBacklash(FocusBacklashN[0].value > 0 ? FocusBacklashN[0].value : 1);
+    return SetFocuserBacklash(FocusBacklashNP[0].getValue() > 0 ? FocusBacklashNP[0].getValue() : 1);
 }
 
 
@@ -656,7 +656,7 @@ IPState PegasusFocusCube::MoveAbsFocuser(uint32_t targetTicks)
     if (!rc)
         return IPS_ALERT;
 
-    FocusAbsPosNP.s = IPS_BUSY;
+    FocusAbsPosNP.setState(IPS_BUSY);
 
     return IPS_BUSY;
 }
@@ -667,17 +667,17 @@ IPState PegasusFocusCube::MoveRelFocuser(FocusDirection dir, uint32_t ticks)
     bool rc = false;
 
     if (dir == FOCUS_INWARD)
-        newPosition = FocusAbsPosN[0].value - ticks;
+        newPosition = FocusAbsPosNP[0].getValue() - ticks;
     else
-        newPosition = FocusAbsPosN[0].value + ticks;
+        newPosition = FocusAbsPosNP[0].getValue() + ticks;
 
     rc = move(newPosition);
 
     if (!rc)
         return IPS_ALERT;
 
-    FocusRelPosN[0].value = ticks;
-    FocusRelPosNP.s       = IPS_BUSY;
+    FocusRelPosNP[0].setValue(ticks);
+    FocusRelPosNP.setState(IPS_BUSY);
 
     return IPS_BUSY;
 }
@@ -694,14 +694,14 @@ void PegasusFocusCube::TimerHit()
 
     if (rc)
     {
-        if (FocusAbsPosNP.s == IPS_BUSY || FocusRelPosNP.s == IPS_BUSY)
+        if (FocusAbsPosNP.getState() == IPS_BUSY || FocusRelPosNP.getState() == IPS_BUSY)
         {
             if (isMoving == false)
             {
-                FocusAbsPosNP.s = IPS_OK;
-                FocusRelPosNP.s = IPS_OK;
-                IDSetNumber(&FocusAbsPosNP, nullptr);
-                IDSetNumber(&FocusRelPosNP, nullptr);
+                FocusAbsPosNP.setState(IPS_OK);
+                FocusRelPosNP.setState(IPS_OK);
+                FocusAbsPosNP.apply();
+                FocusRelPosNP.apply();
                 LOG_INFO("Focuser reached requested position.");
             }
         }
@@ -717,10 +717,10 @@ bool PegasusFocusCube::AbortFocuser()
 
     if (tty_write(PortFD, cmd, 2, &nbytes_written) == TTY_OK)
     {
-        FocusAbsPosNP.s = IPS_IDLE;
-        FocusRelPosNP.s = IPS_IDLE;
-        IDSetNumber(&FocusAbsPosNP, nullptr);
-        IDSetNumber(&FocusRelPosNP, nullptr);
+        FocusAbsPosNP.setState(IPS_IDLE);
+        FocusRelPosNP.setState(IPS_IDLE);
+        FocusAbsPosNP.apply();
+        FocusRelPosNP.apply();
         this->ignoreResponse();
         return true;
     }
