@@ -408,10 +408,59 @@ bool Focuser::getBacklash(uint32_t &steps)
 /******************************************************************************************************
  * SestoSenso2 functions
 *******************************************************************************************************/
-SestoSenso2::SestoSenso2(const std::string &name, int port) : Focuser(name, port) {}
+SestoSenso2::SestoSenso2(const std::string &name, int port) : Focuser(name, port)
+{
+}
+
+bool SestoSenso2::getModel(std::string &model)
+{
+    return m_Communication->get(GENERIC_NODE, "MODNAME", model);
+}
+
+/******************************************************************************************************
+ * Get SubModel for SestoSenso3 variants
+*******************************************************************************************************/
+bool SestoSenso2::getSubModel(std::string &submodel)
+{
+    json jsonRequest = {{"req", {{"srv", {{"GET_MODEL_SUBMODEL", ""}}}}}};
+    json jsonResponse;
+    
+    if (m_Communication->sendRequest(jsonRequest, &jsonResponse))
+    {
+        try
+        {
+            std::string response;
+            jsonResponse["srv"]["GET_MODEL_SUBMODEL"].get_to(response);
+            
+            // Parse: "Model = SESTOSENSO3, SubModel = SESTOSENSO3SC, ARCO = Not enabled"
+            size_t subModelPos = response.find("SubModel = ");
+            if (subModelPos != std::string::npos)
+            {
+                subModelPos += 11; // Length of "SubModel = "
+                size_t commaPos = response.find(",", subModelPos);
+                if (commaPos != std::string::npos)
+                {
+                    submodel = response.substr(subModelPos, commaPos - subModelPos);
+                }
+                else
+                {
+                    // No comma found, take until end of string
+                    submodel = response.substr(subModelPos);
+                }
+                return true;
+            }
+        }
+        catch (json::exception &e)
+        {
+            LOGF_ERROR("Error parsing submodel response: %s", e.what());
+        }
+    }
+    return false;
+}
+
 bool SestoSenso2::storeAsMaxPosition()
 {
-    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "StoreAsMaxPos"}});
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "StoreAsMaxPos-Manual"}});
 }
 
 /******************************************************************************************************
@@ -434,10 +483,67 @@ bool SestoSenso2::goOutToFindMaxPos()
  *
 *******************************************************************************************************/
 bool SestoSenso2::initCalibration()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "Init-Manual"}});
+}
+
+// SestoSenso3 Specific Calibration
+bool SestoSenso2::initSemiAutoCalibration()
 {
     return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "Init"}});
 }
 
+bool SestoSenso2::goInToFindMinPos()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "GoInToFindMinPos"}});
+}
+
+bool SestoSenso2::stopMotor()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "StopMotor"}});
+}
+
+bool SestoSenso2::moveIn(uint32_t steps)
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "MoveIn-" + std::to_string(steps)}});
+}
+
+bool SestoSenso2::moveOut(uint32_t steps)
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "MoveOut-" + std::to_string(steps)}});
+}
+
+bool SestoSenso2::goOutToFindMaxPosSemiAuto()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "GoOutToFindMaxPos"}});
+}
+
+bool SestoSenso2::storeAsMaxPosSemiAuto()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "StoreAsMaxPos"}});
+}
+
+bool SestoSenso2::startAutoCalibration()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "start_auto_cal"}});
+}
+
+bool SestoSenso2::stopCalibration()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "stop_calib"}});
+}
+
+// SestoSenso3 Recovery Delay
+bool SestoSenso2::setRecoveryDelay(int32_t delay)
+{
+    return m_Communication->set(GENERIC_NODE, {{"RECOVER_DELAY", delay}});
+}
+
+bool SestoSenso2::getRecoveryDelay(int32_t &delay)
+{
+    return m_Communication->get(GENERIC_NODE, "RECOVER_DELAY", delay);
+}
+
 /******************************************************************************************************
  *
 *******************************************************************************************************/
@@ -567,6 +673,11 @@ bool Esatto::getVoltageUSB(double &value)
     return m_Communication->getStringAsDouble(GENERIC_NODE, "VIN_USB", value);
 }
 
+bool Esatto::getModel(std::string &model)
+{
+    return m_Communication->get(GENERIC_NODE, "MODNAME", model);
+}
+
 /******************************************************************************************************
  * Arco
 *******************************************************************************************************/
@@ -749,6 +860,12 @@ bool Arco::getFirmwareVersion(std::string &response)
     return true;
 }
 
+bool Arco::getModel(std::string &model)
+{
+    return m_Communication->get(GENERIC_NODE, "MODNAME", model);
+}
+
+
 /******************************************************************************************************
  *
 *******************************************************************************************************/
@@ -766,6 +883,14 @@ GIOTTO::GIOTTO(const std::string &name, int port)
     m_Communication.reset(new Communication(name, port));
 }
 
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool GIOTTO::getModel(std::string &model)
+{
+    return m_Communication->get(GENERIC_NODE, "MODNAME", model);
+}
+
 /******************************************************************************************************
  *
 *******************************************************************************************************/
@@ -820,7 +945,6 @@ ALTO::ALTO(const std::string &name, int port)
     m_Communication.reset(new Communication(name, port));
 }
 
-
 /******************************************************************************************************
  *
 *******************************************************************************************************/
