@@ -3,6 +3,8 @@
     Copyright (C) 2020 Piotr Zyziuk
     Copyright (C) 2020 Jasem Mutlaq (Added Esatto support)
 
+    Jasem Mutlaq 2025: Added SestoSenso3 support.
+    
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
     License as published by the Free Software Foundation; either
@@ -91,8 +93,22 @@ bool SestoSenso2::initProperties()
 
     // Calibration
     CalibrationSP[CALIBRATION_START].fill("CALIBRATION_START", "Start", ISS_OFF);
-    CalibrationSP[CALIBRATION_NEXT].fill("CALIBRATION_NEXT", "Next", ISS_OFF);
+    if (m_SestoSensoModel != SESTOSENSO3_SC) // Only show NEXT for non-SC models
+    {
+        CalibrationSP[CALIBRATION_NEXT].fill("CALIBRATION_NEXT", "Next", ISS_OFF);
+    }
+    else
+    {
+        // For SC models, only START is available, and it's an automatic calibration
+        CalibrationSP.resize(1);
+    }
+
     CalibrationSP.fill(getDeviceName(), "FOCUS_CALIBRATION", "Calibration", MAIN_CONTROL_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
+    if (m_SestoSensoModel == SESTOSENSO3_STANDARD || m_SestoSensoModel == SESTOSENSO3_SC || m_SestoSensoModel == SESTOSENSO3_LS)
+    {
+        RecoveryDelayNP[RECOVERY_DELAY_VALUE].fill("RECOVERY_DELAY", "Recovery Delay (s)", "%.0f", -1, 120, 1, 0);
+        RecoveryDelayNP.fill(getDeviceName(), "RECOVERY_DELAY_PROP", "Recovery Delay", MAIN_CONTROL_TAB, IP_RW, 0, IPS_IDLE);
+    }
 
     // Speed Moves
     FastMoveSP[FASTMOVE_IN].fill("FASTMOVE_IN", "Move In", ISS_OFF);
@@ -100,6 +116,19 @@ bool SestoSenso2::initProperties()
     FastMoveSP[FASTMOVE_STOP].fill("FASTMOVE_STOP", "Stop", ISS_OFF);
     FastMoveSP.fill(getDeviceName(), "FAST_MOVE", "Calibration Move", MAIN_CONTROL_TAB, IP_RW, ISR_ATMOST1, 0, IPS_IDLE);
 
+    // Semi-automatic calibration move switches
+    MoveInOut100SP[MOVE_IN_100].fill("MOVE_IN_100", "Move In 100", ISS_OFF);
+    MoveInOut100SP[MOVE_OUT_100].fill("MOVE_OUT_100", "Move Out 100", ISS_OFF);
+    MoveInOut100SP.fill(getDeviceName(), "SEMI_AUTO_MOVE_100", "Move 100 Steps", MAIN_CONTROL_TAB, IP_RW, ISR_ATMOST1, 0, IPS_IDLE);
+
+    MoveInOut500SP[MOVE_IN_500].fill("MOVE_IN_500", "Move In 500", ISS_OFF);
+    MoveInOut500SP[MOVE_OUT_500].fill("MOVE_OUT_500", "Move Out 500", ISS_OFF);
+    MoveInOut500SP.fill(getDeviceName(), "SEMI_AUTO_MOVE_500", "Move 500 Steps", MAIN_CONTROL_TAB, IP_RW, ISR_ATMOST1, 0, IPS_IDLE);
+
+    MoveInOut1000SP[MOVE_IN_1000].fill("MOVE_IN_1000", "Move In 1000", ISS_OFF);
+    MoveInOut1000SP[MOVE_OUT_1000].fill("MOVE_OUT_1000", "Move Out 1000", ISS_OFF);
+    MoveInOut1000SP.fill(getDeviceName(), "SEMI_AUTO_MOVE_1000", "Move 1000 Steps", MAIN_CONTROL_TAB, IP_RW, ISR_ATMOST1, 0, IPS_IDLE);
+
     // Hold state
     MotorHoldSP[MOTOR_HOLD_ON].fill("HOLD_ON", "Hold On", ISS_OFF);
     MotorHoldSP[MOTOR_HOLD_OFF].fill("HOLD_OFF", "Hold Off", ISS_OFF);
@@ -195,6 +224,21 @@ bool SestoSenso2::updateProperties()
         if (updateVoltageIn())
             defineProperty(VoltageInNP);
 
+        if (m_SestoSensoModel != SESTOSENSO2)
+        {
+            defineProperty(RecoveryDelayNP);
+            int32_t delay = 0;
+            if (m_SestoSenso2->getRecoveryDelay(delay))
+            {
+                RecoveryDelayNP[RECOVERY_DELAY_VALUE].setValue(delay);
+                RecoveryDelayNP.setState(IPS_OK);
+            }
+            else
+            {
+                RecoveryDelayNP.setState(IPS_ALERT);
+            }
+        }
+
         if (getStartupValues())
             LOG_INFO("Parameters updated, focuser ready for use.");
         else
@@ -214,6 +258,11 @@ bool SestoSenso2::updateProperties()
         deleteProperty(MotorApplyPresetSP);
         deleteProperty(MotorApplyUserPresetSP);
         deleteProperty(MotorSaveUserPresetSP);
+
+        if (m_SestoSensoModel == SESTOSENSO3_STANDARD || m_SestoSensoModel == SESTOSENSO3_SC || m_SestoSensoModel == SESTOSENSO3_LS)
+        {
+            deleteProperty(RecoveryDelayNP);
+        }
     }
 
     return true;
@@ -523,20 +572,41 @@ bool SestoSenso2::ISNewSwitch(const char *dev, const char *name, ISState *states
                     CalibrationSP.setState(IPS_BUSY);
                     CalibrationSP.apply();
 
-                    //
-                    // Init
-                    //
-                    if (m_IsSestoSenso2 && m_SestoSenso2->initCalibration() == false)
-                        return false;
+                    if (m_SestoSensoModel == SESTOSENSO3_SC)
+                    {
+                        // SestoSenso3 SC: Automatic Calibration
+                        if (m_SestoSenso2->startAutoCalibration() == false)
+                            return false;
+                        CalibrationMessageTP[0].setText("Automatic Calibration Started. Please wait...");
+                        CalibrationMessageTP.apply();
+                        // No 'NEXT' for SC models, calibration is automatic
+                        cStage = GoToMiddle; // Use GoToMiddle as a placeholder for "in progress"
+                    }
+                    else if (m_SestoSensoModel == SESTOSENSO3_STANDARD || m_SestoSensoModel == SESTOSENSO3_LS)
+                    {
+                        // SestoSenso3 (non-SC): Semi-Automatic Calibration
+                        if (m_SestoSenso2->initSemiAutoCalibration() == false)
+                            return false;
+                        CalibrationMessageTP[0].setText("Semi-Automatic Calibration: Move focuser to MIN position and then press NEXT.");
+                        CalibrationMessageTP.apply();
+                        fetchMotorSettings();
+                        cStage = GoToMiddle;
 
-                    CalibrationMessageTP[0].setText("Set focus in MIN position and then press NEXT.");
-                    CalibrationMessageTP.apply();
-
-                    // Motor hold disabled during calibration init, so fetch new hold state
-                    fetchMotorSettings();
-
-                    // Set next step
-                    cStage = GoToMiddle;
+                        // Define semi-automatic move switches
+                        defineProperty(MoveInOut100SP);
+                        defineProperty(MoveInOut500SP);
+                        defineProperty(MoveInOut1000SP);
+                    }
+                    else // SestoSenso2
+                    {
+                        // Manual Calibration
+                        if (m_SestoSenso2->initCalibration() == false)
+                            return false;
+                        CalibrationMessageTP[0].setText("Manual Calibration: Set focus in MIN position and then press NEXT.");
+                        CalibrationMessageTP.apply();
+                        fetchMotorSettings();
+                        cStage = GoToMiddle;
+                    }
                 }
                 else
                 {
@@ -547,36 +617,56 @@ bool SestoSenso2::ISNewSwitch(const char *dev, const char *name, ISState *states
             }
             else if (current_switch == CALIBRATION_NEXT)
             {
+                if (m_SestoSensoModel == SESTOSENSO3_SC)
+                {
+                    // For SC models, NEXT should not be available, but if somehow triggered, log an error.
+                    LOG_ERROR("CALIBRATION_NEXT triggered for SestoSenso3 SC model, which is not supported.");
+                    CalibrationMessageTP[0].setText("Error: NEXT not applicable for Automatic Calibration.");
+                    CalibrationMessageTP.apply();
+                    CalibrationSP.setState(IPS_ALERT);
+                    CalibrationSP.apply();
+                    return false;
+                }
+
+                // Logic for SestoSenso2 (Manual) and SestoSenso3 (Semi-Automatic)
                 if (cStage == GoToMiddle)
                 {
                     defineProperty(FastMoveSP);
-                    if (m_IsSestoSenso2)
+                    if (m_SestoSensoModel == SESTOSENSO3_STANDARD || m_SestoSensoModel == SESTOSENSO3_LS) // SestoSenso3 Semi-Automatic
                     {
                         if (m_SestoSenso2->storeAsMinPosition() == false)
                             return false;
-
-                        CalibrationMessageTP[0].setText("Press MOVE OUT to move focuser out (CAUTION!)");
+                        CalibrationMessageTP[0].setText("Semi-Automatic Calibration: Use Fast Move to go OUT to find MAX position, then press STOP, then NEXT.");
                         CalibrationMessageTP.apply();
                         cStage = GoMinimum;
                     }
-                    // For Esatto, start moving out immediately
-                    else
+                    else // SestoSenso2 Manual (and Esatto)
                     {
-                        cStage = GoMaximum;
-
-                        ISState fs[1] = { ISS_ON };
-                        const char *fn[1] =  { FastMoveSP[FASTMOVE_OUT].getName() };
-                        ISNewSwitch(getDeviceName(), FastMoveSP.getName(), fs, const_cast<char **>(fn), 1);
+                        if (m_SestoSenso2->storeAsMinPosition() == false)
+                            return false;
+                        CalibrationMessageTP[0].setText("Manual Calibration: Press MOVE OUT to move focuser out (CAUTION!)");
+                        CalibrationMessageTP.apply();
+                        cStage = GoMinimum;
                     }
                 }
                 else if (cStage == GoMinimum)
                 {
-                    if (m_SestoSenso2->storeAsMaxPosition() == false)
-                        return false;
-
-                    CalibrationMessageTP[0].setText("Press NEXT to finish.");
-                    CalibrationMessageTP.apply();
-                    cStage = GoMaximum;
+                    if (m_SestoSensoModel == SESTOSENSO3_STANDARD || m_SestoSensoModel == SESTOSENSO3_LS) // SestoSenso3 Semi-Automatic
+                    {
+                        if (m_SestoSenso2->storeAsMaxPosition() == false)
+                            return false;
+                        CalibrationMessageTP[0].setText("Semi-Automatic Calibration: Press NEXT to finish.");
+                        CalibrationMessageTP.apply();
+                        cStage = GoMaximum;
+                    }
+                    else // SestoSenso2 Manual (and Esatto)
+                    {
+                        if (m_SestoSenso2->storeAsMaxPosition() == false)
+                            return false;
+                        CalibrationMessageTP[0].setText("Manual Calibration: Press NEXT to finish.");
+                        CalibrationMessageTP.apply();
+                        cStage = GoMaximum;
+                    }
                 }
                 else if (cStage == GoMaximum)
                 {
@@ -617,6 +707,11 @@ bool SestoSenso2::ISNewSwitch(const char *dev, const char *name, ISState *states
                     CalibrationMessageTP.apply();
 
                     deleteProperty(FastMoveSP);
+                    // Delete semi-automatic move switches
+                    deleteProperty(MoveInOut100SP);
+                    deleteProperty(MoveInOut500SP);
+                    deleteProperty(MoveInOut1000SP);
+
                     cStage = Complete;
 
                     LOG_INFO("Calibration completed");
@@ -650,18 +745,26 @@ bool SestoSenso2::ISNewSwitch(const char *dev, const char *name, ISState *states
                         return false;
                     break;
                 case FASTMOVE_OUT:
-                    // NOT CORRECT FIX ME
                     // Only use when calibration active?
-                    if (m_IsSestoSenso2)
+                    if (m_SestoSensoModel == SESTOSENSO3_STANDARD || m_SestoSensoModel == SESTOSENSO3_LS) // SestoSenso3 Semi-Automatic
+                    {
+                        if (m_SestoSenso2->goOutToFindMaxPosSemiAuto() == false)
+                        {
+                            return false;
+                        }
+                        CalibrationMessageTP[0].setText("Semi-Automatic Calibration: Press STOP focuser almost at MAX position.");
+                        fetchMotorSettings();
+                    }
+                    else if (m_SestoSensoModel == SESTOSENSO2) // SestoSenso2 Manual
                     {
                         if (m_SestoSenso2->goOutToFindMaxPos() == false)
                         {
                             return false;
                         }
-                        CalibrationMessageTP[0].setText("Press STOP focuser almost at MAX position.");
+                        CalibrationMessageTP[0].setText("Manual Calibration: Press STOP focuser almost at MAX position.");
                         fetchMotorSettings();
                     }
-                    else
+                    else // Esatto
                     {
                         if (m_SestoSenso2->fastMoveOut())
                         {
@@ -672,7 +775,7 @@ bool SestoSenso2::ISNewSwitch(const char *dev, const char *name, ISState *states
                     CalibrationMessageTP.apply();
                     break;
                 case FASTMOVE_STOP:
-                    if (m_SestoSenso2->stop() == false)
+                    if (m_SestoSenso2->stopMotor() == false) // Use generic stopMotor for SestoSenso3
                     {
                         return false;
                     }
@@ -687,6 +790,58 @@ bool SestoSenso2::ISNewSwitch(const char *dev, const char *name, ISState *states
             FastMoveSP.apply();
             return true;
         }
+        // Semi-automatic calibration move switches
+        else if (m_SestoSensoModel == SESTOSENSO3_STANDARD || m_SestoSensoModel == SESTOSENSO3_LS)
+        {
+            if (MoveInOut100SP.isNameMatch(name))
+            {
+                MoveInOut100SP.update(states, names, n);
+                auto current_move_switch = MoveInOut100SP.findOnSwitchIndex();
+                if (current_move_switch == MOVE_IN_100)
+                {
+                    if (m_SestoSenso2->moveIn(100) == false) return false;
+                }
+                else if (current_move_switch == MOVE_OUT_100)
+                {
+                    if (m_SestoSenso2->moveOut(100) == false) return false;
+                }
+                MoveInOut100SP.setState(IPS_IDLE);
+                MoveInOut100SP.apply();
+                return true;
+            }
+            else if (MoveInOut500SP.isNameMatch(name))
+            {
+                MoveInOut500SP.update(states, names, n);
+                auto current_move_switch = MoveInOut500SP.findOnSwitchIndex();
+                if (current_move_switch == MOVE_IN_500)
+                {
+                    if (m_SestoSenso2->moveIn(500) == false) return false;
+                }
+                else if (current_move_switch == MOVE_OUT_500)
+                {
+                    if (m_SestoSenso2->moveOut(500) == false) return false;
+                }
+                MoveInOut500SP.setState(IPS_IDLE);
+                MoveInOut500SP.apply();
+                return true;
+            }
+            else if (MoveInOut1000SP.isNameMatch(name))
+            {
+                MoveInOut1000SP.update(states, names, n);
+                auto current_move_switch = MoveInOut1000SP.findOnSwitchIndex();
+                if (current_move_switch == MOVE_IN_1000)
+                {
+                    if (m_SestoSenso2->moveIn(1000) == false) return false;
+                }
+                else if (current_move_switch == MOVE_OUT_1000)
+                {
+                    if (m_SestoSenso2->moveOut(1000) == false) return false;
+                }
+                MoveInOut1000SP.setState(IPS_IDLE);
+                MoveInOut1000SP.apply();
+                return true;
+            }
+        }
         // Homing
         else if (MotorHoldSP.isNameMatch(name))
         {
@@ -826,6 +981,42 @@ bool SestoSenso2::ISNewNumber(const char *dev, const char *name, double values[]
         MotorCurrentNP.apply();
         return true;
     }
+    else if (RecoveryDelayNP.isNameMatch(name))
+    {
+        RecoveryDelayNP.update(values, names, n);
+        int32_t delay = static_cast<int32_t>(RecoveryDelayNP[RECOVERY_DELAY_VALUE].getValue());
+        if (m_SestoSenso2->setRecoveryDelay(delay))
+        {
+            RecoveryDelayNP.setState(IPS_OK);
+            LOGF_INFO("Recovery Delay set to %d seconds.", delay);
+        }
+        else
+        {
+            RecoveryDelayNP.setState(IPS_ALERT);
+            LOG_ERROR("Failed to set Recovery Delay.");
+        }
+        saveConfig(RecoveryDelayNP);
+        RecoveryDelayNP.apply();
+        return true;
+    }
+    else if ((m_SestoSensoModel != SESTOSENSO2) && RecoveryDelayNP.isNameMatch(name))
+    {
+        RecoveryDelayNP.update(values, names, n);
+        int32_t delay = static_cast<int32_t>(RecoveryDelayNP[RECOVERY_DELAY_VALUE].getValue());
+        if (m_SestoSenso2->setRecoveryDelay(delay))
+        {
+            RecoveryDelayNP.setState(IPS_OK);
+            LOGF_INFO("Recovery Delay set to %d seconds.", delay);
+        }
+        else
+        {
+            RecoveryDelayNP.setState(IPS_ALERT);
+            LOG_ERROR("Failed to set Recovery Delay.");
+        }
+        saveConfig(RecoveryDelayNP);
+        RecoveryDelayNP.apply();
+        return true;
+    }
 
     return INDI::Focuser::ISNewNumber(dev, name, values, names, n);
 }
@@ -951,7 +1142,7 @@ void SestoSenso2::TimerHit()
     if (!isConnected() ||
             FocusAbsPosNP.getState() == IPS_BUSY
             || FocusRelPosNP.getState() == IPS_BUSY ||
-            (m_IsSestoSenso2 && CalibrationSP.getState() == IPS_BUSY))
+            CalibrationSP.getState() == IPS_BUSY)
     {
         SetTimer(getCurrentPollingPeriod());
         return;
@@ -1050,9 +1241,57 @@ bool SestoSenso2::Ack()
         {
             return false;
         }
+
+        std::string modelName;
+        if (m_SestoSenso2->getModel(modelName))
+        {
+            LOGF_INFO("Model name: %s", modelName.c_str());
+            
+            // Check if it's a SestoSenso3 variant (requires submodel query)
+            if (modelName.find("SESTOSENSO3") != std::string::npos)
+            {
+                // Query submodel to determine specific variant
+                std::string subModel;
+                if (m_SestoSenso2->getSubModel(subModel))
+                {
+                    LOGF_INFO("SubModel: %s", subModel.c_str());
+                    
+                    if (subModel.find("SESTOSENSO3SC") != std::string::npos)
+                    {
+                        m_SestoSensoModel = SESTOSENSO3_SC;
+                        LOG_INFO("Detected: SestoSenso3 SC (Automatic Calibration)");
+                    }
+                    else if (subModel.find("SESTOSENSO3LS") != std::string::npos)
+                    {
+                        m_SestoSensoModel = SESTOSENSO3_LS;
+                        LOG_INFO("Detected: SestoSenso3 LS (Manual + Semi-Automatic Calibration)");
+                    }
+                    else
+                    {
+                        m_SestoSensoModel = SESTOSENSO3_STANDARD;
+                        LOG_INFO("Detected: SestoSenso3 Standard (Manual + Semi-Automatic Calibration)");
+                    }
+                }
+                else
+                {
+                    // Fallback if submodel query fails
+                    m_SestoSensoModel = SESTOSENSO3_STANDARD;
+                    LOG_WARN("Failed to query submodel, defaulting to SestoSenso3 Standard");
+                }
+            }
+            else if (modelName.find("SESTOSENSO2") != std::string::npos)
+            {
+                m_SestoSensoModel = SESTOSENSO2;
+                LOG_INFO("Detected: SestoSenso2 (Manual Calibration)");
+            }
+            else
+            {
+                m_SestoSensoModel = SESTOSENSO2;
+                LOGF_WARN("Unknown model '%s', defaulting to SestoSenso2", modelName.c_str());
+            }
+        }
     }
 
-    m_IsSestoSenso2 = !strstr(response.c_str(), "ESATTO");
     FirmwareTP[FIRMWARE_SN].setText(response.c_str());
 
     if (m_SestoSenso2->getFirmwareVersion(response))
@@ -1109,4 +1348,3 @@ bool SestoSenso2::saveConfigItems(FILE *fp)
     MotorCurrentNP.save(fp);
     return true;
 }
-
