@@ -121,6 +121,27 @@ class LX200AM5 : public LX200Generic
         // Meridian Limit
         INDI::PropertyNumber MeridianLimitNP {1};
 
+        // Altitude Limits
+        INDI::PropertySwitch AltitudeLimitSP {3};
+        enum
+        {
+            ALT_LIMIT_ENABLE,
+            ALT_LIMIT_DISABLE,
+            ALT_LIMIT_GET
+        };
+        INDI::PropertyNumber AltitudeLimitUpperNP {1};
+        INDI::PropertyNumber AltitudeLimitLowerNP {1};
+
+        // Multi-Star Alignment
+        INDI::PropertySwitch MultiStarAlignSP {1};
+        enum
+        {
+            CLEAR_ALIGNMENT_DATA
+        };
+
+        // Variable Slew Speed
+        INDI::PropertyNumber VariableSlewRateNP {1};
+
 
         //////////////////////////////////////////////////////////////////////////////////
         /// AM5 Specific
@@ -129,8 +150,23 @@ class LX200AM5 : public LX200Generic
 
         // Homing
         bool goHome();
+        bool park();
         bool setHome();
 
+        // Altitude Limits
+        bool setAltitudeLimitEnabled(bool enable);
+        bool getAltitudeLimitStatus();
+        bool setAltitudeLimitUpper(double limit);
+        bool getAltitudeLimitUpper();
+        bool setAltitudeLimitLower(double limit);
+        bool getAltitudeLimitLower();
+
+        // Multi-Star Alignment
+        bool clearMultiStarAlignmentData();
+
+        // Variable Slew Speed
+        bool setVariableSlewRate(double rate);
+
         // Guide Rate
         bool setGuideRate(double value);
         bool getGuideRate();
@@ -166,6 +202,8 @@ class LX200AM5 : public LX200Generic
         // Maximum buffer for sending/receiving.
         static constexpr const uint8_t DRIVER_LEN {64};
         // Slew Modes
-        static constexpr const uint8_t SLEW_MODES {9};
+        static constexpr const uint8_t SLEW_MODES {10};
         static constexpr const char * MERIDIAN_FLIP_TAB {"Meridian Flip"};
+        static constexpr const char * ALTITUDE_LIMIT_TAB {"Altitude Limits"};
+        static constexpr const char * ALIGNMENT_TAB {"Alignment"};
 };
